==> openvdb-12.1.1-2-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/Metadata_8h.js <==
var Metadata_8h =
[
    [ "Metadata", "classopenvdb_1_1v12__1_1_1Metadata.html", "classopenvdb_1_1v12__1_1_1Metadata" ],
    [ "UnknownMetadata", "classopenvdb_1_1v12__1_1_1UnknownMetadata.html", "classopenvdb_1_1v12__1_1_1UnknownMetadata" ],
    [ "TypedMetadata< T >", "classopenvdb_1_1v12__1_1_1TypedMetadata.html", "classopenvdb_1_1v12__1_1_1TypedMetadata" ],
    [ "openvdb::v12_1::BoolMetadata", "namespaceopenvdb_1_1v12__1.html#aeefccbdae828124c5f4d2ceff34944e9", null ],
    [ "openvdb::v12_1::DoubleMetadata", "namespaceopenvdb_1_1v12__1.html#afa3847988104e135c5f4ae424836cdb7", null ],
    [ "openvdb::v12_1::FloatMetadata", "namespaceopenvdb_1_1v12__1.html#a2070a667d3bbc262fb41fddcb1f327ad", null ],
    [ "openvdb::v12_1::Int32Metadata", "namespaceopenvdb_1_1v12__1.html#a5a108eeb1e1ef97b09f3bf2d9bb76384", null ],
    [ "openvdb::v12_1::Int64Metadata", "namespaceopenvdb_1_1v12__1.html#af074fb9a9f7bf0cc74cf2160eeb609e0", null ],
    [ "openvdb::v12_1::Mat4DMetadata", "namespaceopenvdb_1_1v12__1.html#a60941cfbfde284759f9bb90261a50595", null ],
    [ "openvdb::v12_1::Mat4SMetadata", "namespaceopenvdb_1_1v12__1.html#ae3df02d240c0ee97f9be0bec983ec446", null ],
    [ "openvdb::v12_1::StringMetadata", "namespaceopenvdb_1_1v12__1.html#aac96903b37f9acf362c8bac8729ce9a6", null ],
    [ "openvdb::v12_1::Vec2DMetadata", "namespaceopenvdb_1_1v12__1.html#a3d8bcbfdff0b43d209654496ef1b305d", null ],
    [ "openvdb::v12_1::Vec2IMetadata", "namespaceopenvdb_1_1v12__1.html#a804ea716fee4f315a330dc22e8245762", null ],
    [ "openvdb::v12_1::Vec2SMetadata", "namespaceopenvdb_1_1v12__1.html#ad85e2d3af443b10afa7300361d385d81", null ],
    [ "openvdb::v12_1::Vec3DMetadata", "namespaceopenvdb_1_1v12__1.html#a543541af5d9ddcd7e7c894ba032b5a2d", null ],
    [ "openvdb::v12_1::Vec3IMetadata", "namespaceopenvdb_1_1v12__1.html#ae43faa34a286499d22b014d1d6c6b0d6", null ],
    [ "openvdb::v12_1::Vec3SMetadata", "namespaceopenvdb_1_1v12__1.html#ac82fd327fdb051212cc71e10aa28b7eb", null ],
    [ "openvdb::v12_1::Vec4DMetadata", "namespaceopenvdb_1_1v12__1.html#a1338ab1fba5f1d9520427a4ee5a43345", null ],
    [ "openvdb::v12_1::Vec4IMetadata", "namespaceopenvdb_1_1v12__1.html#adc8f07e9f425efe5d4fde72130ff6bb8", null ],
    [ "openvdb::v12_1::Vec4SMetadata", "namespaceopenvdb_1_1v12__1.html#ab7537bae8c0654f2de8bc6e96e644203", null ],
    [ "openvdb::v12_1::operator<<", "namespaceopenvdb_1_1v12__1.html#a7ea4a9046558b7ec2cc44a7e34bc6b75", null ]
];

==> openvdb-12.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/Metadata_8h.js <==
var Metadata_8h =
[
    [ "Metadata", "classopenvdb_1_1v12__1_1_1Metadata.html", "classopenvdb_1_1v12__1_1_1Metadata" ],
    [ "UnknownMetadata", "classopenvdb_1_1v12__1_1_1UnknownMetadata.html", "classopenvdb_1_1v12__1_1_1UnknownMetadata" ],
    [ "TypedMetadata&lt; T &gt;", "classopenvdb_1_1v12__1_1_1TypedMetadata.html", "classopenvdb_1_1v12__1_1_1TypedMetadata" ],
    [ "openvdb::v12_1::BoolMetadata", "namespaceopenvdb_1_1v12__1.html#aeefccbdae828124c5f4d2ceff34944e9", null ],
    [ "openvdb::v12_1::DoubleMetadata", "namespaceopenvdb_1_1v12__1.html#afa3847988104e135c5f4ae424836cdb7", null ],
    [ "openvdb::v12_1::FloatMetadata", "namespaceopenvdb_1_1v12__1.html#a2070a667d3bbc262fb41fddcb1f327ad", null ],
    [ "openvdb::v12_1::Int32Metadata", "namespaceopenvdb_1_1v12__1.html#a5a108eeb1e1ef97b09f3bf2d9bb76384", null ],
    [ "openvdb::v12_1::Int64Metadata", "namespaceopenvdb_1_1v12__1.html#af074fb9a9f7bf0cc74cf2160eeb609e0", null ],
    [ "openvdb::v12_1::Mat4DMetadata", "namespaceopenvdb_1_1v12__1.html#a60941cfbfde284759f9bb90261a50595", null ],
    [ "openvdb::v12_1::Mat4SMetadata", "namespaceopenvdb_1_1v12__1.html#ae3df02d240c0ee97f9be0bec983ec446", null ],
    [ "openvdb::v12_1::StringMetadata", "namespaceopenvdb_1_1v12__1.html#aac96903b37f9acf362c8bac8729ce9a6", null ],
    [ "openvdb::v12_1::Vec2DMetadata", "namespaceopenvdb_1_1v12__1.html#a3d8bcbfdff0b43d209654496ef1b305d", null ],
    [ "openvdb::v12_1::Vec2IMetadata", "namespaceopenvdb_1_1v12__1.html#a804ea716fee4f315a330dc22e8245762", null ],
    [ "openvdb::v12_1::Vec2SMetadata", "namespaceopenvdb_1_1v12__1.html#ad85e2d3af443b10afa7300361d385d81", null ],
    [ "openvdb::v12_1::Vec3DMetadata", "namespaceopenvdb_1_1v12__1.html#a543541af5d9ddcd7e7c894ba032b5a2d", null ],
    [ "openvdb::v12_1::Vec3IMetadata", "namespaceopenvdb_1_1v12__1.html#ae43faa34a286499d22b014d1d6c6b0d6", null ],
    [ "openvdb::v12_1::Vec3SMetadata", "namespaceopenvdb_1_1v12__1.html#ac82fd327fdb051212cc71e10aa28b7eb", null ],
    [ "openvdb::v12_1::Vec4DMetadata", "namespaceopenvdb_1_1v12__1.html#a1338ab1fba5f1d9520427a4ee5a43345", null ],
    [ "openvdb::v12_1::Vec4IMetadata", "namespaceopenvdb_1_1v12__1.html#adc8f07e9f425efe5d4fde72130ff6bb8", null ],
    [ "openvdb::v12_1::Vec4SMetadata", "namespaceopenvdb_1_1v12__1.html#ab7537bae8c0654f2de8bc6e96e644203", null ],
    [ "openvdb::v12_1::operator<<", "namespaceopenvdb_1_1v12__1.html#a7ea4a9046558b7ec2cc44a7e34bc6b75", null ]
];
